@@ -6,8 +6,8 @@ import (
 	"github.com/git-town/git-town/v15/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v15/internal/cli/dialog/components/list"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 const (
