@@ -12,7 +12,6 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/execute"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
 	"github.com/git-town/git-town/v15/internal/undo/undoconfig"
@@ -21,6 +20,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/vm/opcodes"
 	"github.com/git-town/git-town/v15/internal/vm/program"
 	"github.com/git-town/git-town/v15/internal/vm/runstate"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -44,7 +44,7 @@ func compressCmd() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
 	addMessageFlag, readMessageFlag := flags.CommitMessage("customize the commit message")
-	addStackFlag, readStackFlag := flags.Bool("stack", "s", "Compress the entire stack", flags.FlagTypeNonPersistent)
+	addStackFlag, readStackFlag := flags.Stack("Compress the entire stack")
 	cmd := cobra.Command{
 		Use:   compressCommand,
 		Args:  cobra.NoArgs,
@@ -61,7 +61,7 @@ func compressCmd() *cobra.Command {
 	return &cmd
 }
 
-func executeCompress(dryRun configdomain.DryRun, verbose configdomain.Verbose, message Option[gitdomain.CommitMessage], stack bool) error {
+func executeCompress(dryRun configdomain.DryRun, verbose configdomain.Verbose, message Option[gitdomain.CommitMessage], compressEntireStack configdomain.FullStack) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
 		DryRun:           dryRun,
 		PrintBranchNames: true,
@@ -73,7 +73,7 @@ func executeCompress(dryRun configdomain.DryRun, verbose configdomain.Verbose, m
 	if err != nil {
 		return err
 	}
-	data, exit, err := determineCompressBranchesData(repo, dryRun, verbose, message, stack)
+	data, exit, err := determineCompressBranchesData(repo, dryRun, verbose, message, compressEntireStack)
 	if err != nil || exit {
 		return err
 	}
@@ -113,7 +113,7 @@ func executeCompress(dryRun configdomain.DryRun, verbose configdomain.Verbose, m
 type compressBranchesData struct {
 	branchesSnapshot    gitdomain.BranchesSnapshot
 	branchesToCompress  []compressBranchData
-	compressEntireStack bool
+	compressEntireStack configdomain.FullStack // TODO: delete this
 	config              config.ValidatedConfig
 	dialogTestInputs    components.TestInputs
 	dryRun              configdomain.DryRun
@@ -132,7 +132,7 @@ type compressBranchData struct {
 	parentBranch     gitdomain.LocalBranchName
 }
 
-func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun configdomain.DryRun, verbose configdomain.Verbose, message Option[gitdomain.CommitMessage], compressEntireStack bool) (data compressBranchesData, exit bool, err error) {
+func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun configdomain.DryRun, verbose configdomain.Verbose, message Option[gitdomain.CommitMessage], compressEntireStack configdomain.FullStack) (data compressBranchesData, exit bool, err error) {
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
@@ -271,10 +271,10 @@ func compressBranchProgram(prog Mutable[program.Program], data compressBranchDat
 		return
 	}
 	prog.Value.Add(&opcodes.Checkout{Branch: data.name})
-	prog.Value.Add(&opcodes.ResetCommitsInCurrentBranch{Parent: data.parentBranch})
+	prog.Value.Add(&opcodes.ResetCurrentBranch{Base: data.parentBranch.BranchName()})
 	prog.Value.Add(&opcodes.CommitSquashedChanges{Message: Some(data.newCommitMessage)})
-	if data.hasTracking && online.Bool() {
-		prog.Value.Add(&opcodes.ForcePushCurrentBranch{})
+	if data.hasTracking && online.IsTrue() {
+		prog.Value.Add(&opcodes.ForcePushCurrentBranch{ForceIfIncludes: true})
 	}
 }
 
