@@ -13,7 +13,6 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/execute"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
@@ -22,6 +21,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/vm/program"
 	"github.com/git-town/git-town/v15/internal/vm/runstate"
 	"github.com/git-town/git-town/v15/internal/vm/statefile"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -144,7 +144,7 @@ func determineContinueData(repo execute.OpenRepoResult, verbose configdomain.Ver
 			Config:          repo.UnvalidatedConfig.Config.Get(),
 			HostingPlatform: validatedConfig.Config.HostingPlatform,
 			Log:             print.Logger{},
-			OriginURL:       originURL,
+			RemoteURL:       originURL,
 		})
 	}
 	return continueData{
