@@ -11,9 +11,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/execute"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/messages"
 	configInterpreter "github.com/git-town/git-town/v15/internal/vm/interpreter/config"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -135,46 +135,17 @@ func determineContributeData(args []string, repo execute.OpenRepoResult) (contri
 	if err != nil {
 		return contributeData{}, err
 	}
-	branchesToMark := commandconfig.BranchesAndTypes{}
-	var branchToCheckout Option[gitdomain.LocalBranchName]
-	switch len(args) {
-	case 0:
-		currentBranch, hasCurrentBranch := branchesSnapshot.Active.Get()
-		if !hasCurrentBranch {
-			return contributeData{}, errors.New(messages.CurrentBranchCannotDetermine)
-		}
-		branchesToMark.Add(currentBranch, repo.UnvalidatedConfig.Config.Get())
-		branchToCheckout = None[gitdomain.LocalBranchName]()
-	case 1:
-		branch := gitdomain.NewLocalBranchName(args[0])
-		branchesToMark.Add(branch, repo.UnvalidatedConfig.Config.Get())
-		trackingBranchName := branch.TrackingBranch()
-		branchInfo, hasBranchInfo := branchesSnapshot.Branches.FindByRemoteName(trackingBranchName).Get()
-		if !hasBranchInfo {
-			return contributeData{}, fmt.Errorf(messages.BranchDoesntExist, branch.String())
-		}
-		if branchInfo.SyncStatus == gitdomain.SyncStatusRemoteOnly {
-			branchToCheckout = Some(branch)
-		} else {
-			branchToCheckout = None[gitdomain.LocalBranchName]()
-		}
-	default:
-		branchesToMark.AddMany(gitdomain.NewLocalBranchNames(args...), repo.UnvalidatedConfig.Config.Get())
-		branchToCheckout = None[gitdomain.LocalBranchName]()
-	}
+	branchesToMakeContribution, branchToCheckout, err := execute.BranchesToMark(args, branchesSnapshot, repo.UnvalidatedConfig.Config.Get())
 	return contributeData{
 		allBranches:           branchesSnapshot.Branches,
 		beginBranchesSnapshot: branchesSnapshot,
 		branchToCheckout:      branchToCheckout,
-		branchesToMark:        branchesToMark,
-	}, nil
+		branchesToMark:        branchesToMakeContribution,
+	}, err
 }
 
 func validateContributeData(data contributeData) error {
 	for branchName, branchType := range data.branchesToMark {
-		if !data.allBranches.HasLocalBranch(branchName) && !data.allBranches.HasMatchingTrackingBranchFor(branchName) {
-			return fmt.Errorf(messages.BranchDoesntExist, branchName)
-		}
 		switch branchType {
 		case configdomain.BranchTypeMainBranch:
 			return errors.New(messages.MainBranchCannotMakeContribution)
@@ -184,6 +155,14 @@ func validateContributeData(data contributeData) error {
 			return fmt.Errorf(messages.BranchIsAlreadyContribution, branchName)
 		case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeObservedBranch, configdomain.BranchTypeParkedBranch, configdomain.BranchTypePrototypeBranch:
 		}
+		hasLocalBranch := data.allBranches.HasLocalBranch(branchName)
+		hasRemoteBranch := data.allBranches.HasMatchingTrackingBranchFor(branchName)
+		if !hasLocalBranch && !hasRemoteBranch {
+			return fmt.Errorf(messages.BranchDoesntExist, branchName)
+		}
+		if hasLocalBranch && !hasRemoteBranch {
+			return fmt.Errorf(messages.ContributeBranchIsLocal, branchName)
+		}
 	}
 	return nil
 }
