@@ -16,7 +16,6 @@ import (
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
@@ -25,6 +24,7 @@ import (
 	configInterpreter "github.com/git-town/git-town/v15/internal/vm/interpreter/config"
 	fullInterpreter "github.com/git-town/git-town/v15/internal/vm/interpreter/full"
 	"github.com/git-town/git-town/v15/internal/vm/runstate"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -243,8 +243,10 @@ func determineHackData(args []string, repo execute.OpenRepoResult, dryRun config
 		return data, false, fmt.Errorf(messages.BranchAlreadyExistsRemotely, targetBranch)
 	}
 	branchNamesToSync := gitdomain.LocalBranchNames{validatedConfig.Config.MainBranch}
-	var branchesToSync gitdomain.BranchInfos
-	branchesToSync, err = branchesSnapshot.Branches.Select(branchNamesToSync...)
+	branchesToSync, err := branchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.Config.MainBranch)
+	if err != nil {
+		return data, false, err
+	}
 	data = Left[appendFeatureData, convertToFeatureData](appendFeatureData{
 		allBranches:               branchesSnapshot.Branches,
 		branchesSnapshot:          branchesSnapshot,
