@@ -152,11 +152,10 @@ func determineKillData(args []string, repo execute.OpenRepoResult, dryRun config
 		return data, exit, fmt.Errorf(messages.KillBranchOtherWorktree, branchNameToKill)
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
-	branchesToKill := gitdomain.LocalBranchNames{branchNameToKill}
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesSnapshot:   branchesSnapshot,
-		BranchesToValidate: branchesToKill,
+		BranchesToValidate: gitdomain.LocalBranchNames{},
 		DialogTestInputs:   dialogTestInputs,
 		Frontend:           repo.Frontend,
 		Git:                repo.Git,
@@ -242,10 +241,8 @@ func killLocalBranch(prog, finalUndoProgram Mutable[program.Program], data killD
 	if localBranchToKill, hasLocalBranchToKill := data.branchToKillInfo.LocalName.Get(); hasLocalBranchToKill {
 		if data.initialBranch == localBranchToKill {
 			if data.hasOpenChanges {
-				prog.Value.Add(&opcodes.CommitOpenChanges{
-					AddAll:  true,
-					Message: "Committing WIP for git town undo",
-				})
+				prog.Value.Add(&opcodes.StageOpenChanges{})
+				prog.Value.Add(&opcodes.CommitOpenChanges{Message: "Committing WIP for git town undo"})
 				// update the registered initial SHA for this branch so that undo restores the just committed changes
 				prog.Value.Add(&opcodes.UpdateInitialBranchLocalSHA{Branch: data.initialBranch})
 				// when undoing, manually undo the just committed changes so that they are uncommitted again
