@@ -11,9 +11,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/execute"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/messages"
 	configInterpreter "github.com/git-town/git-town/v15/internal/vm/interpreter/config"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -74,7 +74,7 @@ func executeOffline(args []string, verbose configdomain.Verbose) error {
 }
 
 func displayOfflineStatus(config configdomain.UnvalidatedConfig) {
-	fmt.Println(format.Bool(config.Offline.Bool()))
+	fmt.Println(format.Bool(config.Offline.IsTrue()))
 }
 
 func setOfflineStatus(text string, config config.UnvalidatedConfig) error {
