@@ -6,6 +6,7 @@ import (
 	"io"
 	"os"
 
+	"github.com/git-town/git-town/v15/internal/browser"
 	"github.com/git-town/git-town/v15/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v15/internal/cli/flags"
 	"github.com/git-town/git-town/v15/internal/cli/print"
@@ -79,8 +80,9 @@ func executePropose(dryRun configdomain.DryRun, verbose configdomain.Verbose, ti
 	if err != nil || exit {
 		return err
 	}
-	if err = validateProposeData(data); err != nil {
-		return err
+	if existingProposalURL, hasExistingProposal := data.existingProposalURL.Get(); hasExistingProposal {
+		browser.Open(existingProposalURL, repo.Frontend, repo.Backend)
+		return nil
 	}
 	runProgram := proposeProgram(data)
 	runState := runstate.RunState{
@@ -116,21 +118,23 @@ func executePropose(dryRun configdomain.DryRun, verbose configdomain.Verbose, ti
 }
 
 type proposeData struct {
-	allBranches       gitdomain.BranchInfos
-	branchesSnapshot  gitdomain.BranchesSnapshot
-	branchesToSync    []configdomain.BranchToSync
-	config            config.ValidatedConfig
-	connector         Option[hostingdomain.Connector]
-	dialogTestInputs  components.TestInputs
-	dryRun            configdomain.DryRun
-	hasOpenChanges    bool
-	initialBranch     gitdomain.LocalBranchName
-	initialBranchType configdomain.BranchType
-	previousBranch    Option[gitdomain.LocalBranchName]
-	proposalBody      gitdomain.ProposalBody
-	proposalTitle     gitdomain.ProposalTitle
-	remotes           gitdomain.Remotes
-	stashSize         gitdomain.StashSize
+	allBranches         gitdomain.BranchInfos
+	branchToPropose     gitdomain.LocalBranchName
+	branchTypeToPropose configdomain.BranchType
+	branchesSnapshot    gitdomain.BranchesSnapshot
+	branchesToSync      []configdomain.BranchToSync
+	config              config.ValidatedConfig
+	connector           Option[hostingdomain.Connector]
+	dialogTestInputs    components.TestInputs
+	dryRun              configdomain.DryRun
+	existingProposalURL Option[string]
+	hasOpenChanges      bool
+	initialBranch       gitdomain.LocalBranchName
+	previousBranch      Option[gitdomain.LocalBranchName]
+	proposalBody        gitdomain.ProposalBody
+	proposalTitle       gitdomain.ProposalTitle
+	remotes             gitdomain.Remotes
+	stashSize           gitdomain.StashSize
 }
 
 func determineProposeData(repo execute.OpenRepoResult, dryRun configdomain.DryRun, verbose configdomain.Verbose, title gitdomain.ProposalTitle, body gitdomain.ProposalBody, bodyFile gitdomain.ProposalBodyFile) (data proposeData, exit bool, err error) {
@@ -169,6 +173,7 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun configdomain.DryRu
 	if !hasInitialBranch {
 		return data, false, errors.New(messages.CurrentBranchCannotDetermine)
 	}
+	branchToPropose := initialBranch
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesSnapshot:   branchesSnapshot,
@@ -184,10 +189,17 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun configdomain.DryRu
 	if err != nil || exit {
 		return data, exit, err
 	}
-	initialBranchType := validatedConfig.Config.BranchType(initialBranch)
-	var connector Option[hostingdomain.Connector]
+	branchTypeToPropose := validatedConfig.Config.BranchType(branchToPropose)
+	if err = validateBranchTypeToPropose(branchTypeToPropose); err != nil {
+		return data, false, err
+	}
+	parentOfBranchToPropose, hasParentBranch := validatedConfig.Config.Lineage.Parent(branchToPropose).Get()
+	if !hasParentBranch {
+		return data, false, fmt.Errorf(messages.ProposalNoParent, branchToPropose)
+	}
+	var connectorOpt Option[hostingdomain.Connector]
 	if originURL, hasOriginURL := validatedConfig.OriginURL().Get(); hasOriginURL {
-		connector, err = hosting.NewConnector(hosting.NewConnectorArgs{
+		connectorOpt, err = hosting.NewConnector(hosting.NewConnectorArgs{
 			Config:          *validatedConfig.Config.UnvalidatedConfig,
 			HostingPlatform: validatedConfig.Config.HostingPlatform,
 			Log:             print.Logger{},
@@ -197,10 +209,19 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun configdomain.DryRu
 			return data, false, err
 		}
 	}
-	if connector.IsNone() {
+	existingProposalURL := None[string]()
+	connector, hasConnector := connectorOpt.Get()
+	if !hasConnector {
 		return data, false, hostingdomain.UnsupportedServiceError()
 	}
-	branchNamesToSync := validatedConfig.Config.Lineage.BranchAndAncestors(initialBranch)
+	existingProposalOpt, err := connector.FindProposal(initialBranch, parentOfBranchToPropose)
+	if err != nil {
+		existingProposalOpt = None[hostingdomain.Proposal]()
+	}
+	if existingProposal, hasExistingProposal := existingProposalOpt.Get(); hasExistingProposal {
+		existingProposalURL = Some(existingProposal.URL)
+	}
+	branchNamesToSync := validatedConfig.Config.Lineage.BranchAndAncestors(branchToPropose)
 	branchesToSync, err := branchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.Config.MainBranch)
 	if err != nil {
 		return data, false, err
@@ -224,21 +245,23 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun configdomain.DryRu
 		}
 	}
 	return proposeData{
-		allBranches:       branchesSnapshot.Branches,
-		branchesSnapshot:  branchesSnapshot,
-		branchesToSync:    branchesToSync,
-		config:            validatedConfig,
-		connector:         connector,
-		dialogTestInputs:  dialogTestInputs,
-		dryRun:            dryRun,
-		hasOpenChanges:    repoStatus.OpenChanges,
-		initialBranch:     initialBranch,
-		initialBranchType: initialBranchType,
-		previousBranch:    previousBranch,
-		proposalBody:      bodyText,
-		proposalTitle:     title,
-		remotes:           remotes,
-		stashSize:         stashSize,
+		allBranches:         branchesSnapshot.Branches,
+		branchToPropose:     branchToPropose,
+		branchTypeToPropose: branchTypeToPropose,
+		branchesSnapshot:    branchesSnapshot,
+		branchesToSync:      branchesToSync,
+		config:              validatedConfig,
+		connector:           connectorOpt,
+		dialogTestInputs:    dialogTestInputs,
+		dryRun:              dryRun,
+		existingProposalURL: existingProposalURL,
+		hasOpenChanges:      repoStatus.OpenChanges,
+		initialBranch:       initialBranch,
+		previousBranch:      previousBranch,
+		proposalBody:        bodyText,
+		proposalTitle:       title,
+		remotes:             remotes,
+		stashSize:           stashSize,
 	}, false, err
 }
 
@@ -255,8 +278,8 @@ func proposeProgram(data proposeData) program.Program {
 			PushBranches:       true,
 		})
 	}
-	if data.initialBranchType == configdomain.BranchTypePrototypeBranch {
-		prog.Value.Add(&opcodes.RemoveFromPrototypeBranches{Branch: data.initialBranch})
+	if data.branchTypeToPropose == configdomain.BranchTypePrototypeBranch {
+		prog.Value.Add(&opcodes.RemoveFromPrototypeBranches{Branch: data.branchToPropose})
 	}
 	previousBranchCandidates := gitdomain.LocalBranchNames{}
 	if previousBranch, hasPreviousBranch := data.previousBranch.Get(); hasPreviousBranch {
@@ -269,7 +292,7 @@ func proposeProgram(data proposeData) program.Program {
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
 	prog.Value.Add(&opcodes.CreateProposal{
-		Branch:        data.initialBranch,
+		Branch:        data.branchToPropose,
 		MainBranch:    data.config.Config.MainBranch,
 		ProposalBody:  data.proposalBody,
 		ProposalTitle: data.proposalTitle,
@@ -277,9 +300,8 @@ func proposeProgram(data proposeData) program.Program {
 	return prog.Get()
 }
 
-func validateProposeData(data proposeData) error {
-	initialBranchType := data.config.Config.BranchType(data.initialBranch)
-	switch initialBranchType {
+func validateBranchTypeToPropose(branchType configdomain.BranchType) error {
+	switch branchType {
 	case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeParkedBranch, configdomain.BranchTypePrototypeBranch:
 		return nil
 	case configdomain.BranchTypeMainBranch:
@@ -291,5 +313,5 @@ func validateProposeData(data proposeData) error {
 	case configdomain.BranchTypePerennialBranch:
 		return errors.New(messages.PerennialBranchCannotPropose)
 	}
-	panic(fmt.Sprintf("unhandled branch type: %v", initialBranchType))
+	return nil
 }
