@@ -4,22 +4,18 @@ import (
 	"strconv"
 
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // whether all created branches should be prototype
 type CreatePrototypeBranches bool
 
-func (self CreatePrototypeBranches) Bool() bool {
+func (self CreatePrototypeBranches) IsTrue() bool {
 	return bool(self)
 }
 
-func (self CreatePrototypeBranches) IsTrue() bool {
-	return self.Bool()
-}
-
 func (self CreatePrototypeBranches) String() string {
-	return strconv.FormatBool(self.Bool())
+	return strconv.FormatBool(bool(self))
 }
 
 // deserializes the given Git configuration value into a CreatePrototypeBranches instance
