@@ -4,23 +4,19 @@ import (
 	"strconv"
 
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // PushHook contains the push-hook configuration setting.
 type PushHook bool
 
-func (pushHook PushHook) Bool() bool {
-	return bool(pushHook)
-}
-
-func (pushHook PushHook) Negate() NoPushHook {
-	boolValue := bool(pushHook)
+func (self PushHook) Negate() NoPushHook {
+	boolValue := bool(self)
 	return NoPushHook(!boolValue)
 }
 
-func (pushHook PushHook) String() string {
-	return strconv.FormatBool(pushHook.Bool())
+func (self PushHook) String() string {
+	return strconv.FormatBool(bool(self))
 }
 
 func ParsePushHook(value, source string) (Option[PushHook], error) {
@@ -33,7 +29,3 @@ func ParsePushHook(value, source string) (Option[PushHook], error) {
 
 // NoPushHook helps using the type checker to verify correct negation of the push-hook configuration setting.
 type NoPushHook bool
-
-func (noPushHook NoPushHook) Bool() bool {
-	return bool(noPushHook)
-}
