@@ -4,18 +4,18 @@ import (
 	"strconv"
 
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // ShipDeleteTrackingBranch contains the configuration setting about whether to delete the tracking branch when shipping.
 type ShipDeleteTrackingBranch bool
 
-func (self ShipDeleteTrackingBranch) Bool() bool {
+func (self ShipDeleteTrackingBranch) IsTrue() bool {
 	return bool(self)
 }
 
 func (self ShipDeleteTrackingBranch) String() string {
-	return strconv.FormatBool(self.Bool())
+	return strconv.FormatBool(bool(self))
 }
 
 func ParseShipDeleteTrackingBranch(value, source string) (Option[ShipDeleteTrackingBranch], error) {
