@@ -4,7 +4,7 @@ import (
 	"testing"
 
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -15,7 +15,10 @@ func TestNewSyncStrategy(t *testing.T) {
 		t.Parallel()
 		tests := map[string]Option[configdomain.SyncStrategy]{
 			"":       None[configdomain.SyncStrategy](),
+			" ":      None[configdomain.SyncStrategy](),
 			"merge":  Some(configdomain.SyncStrategyMerge),
+			"merge ": Some(configdomain.SyncStrategyMerge),
+			" merge": Some(configdomain.SyncStrategyMerge),
 			"Merge":  Some(configdomain.SyncStrategyMerge),
 			"MERGE":  Some(configdomain.SyncStrategyMerge),
 			"rebase": Some(configdomain.SyncStrategyRebase),
