@@ -7,7 +7,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/config/configfile"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -57,6 +57,7 @@ func TestSave(t *testing.T) {
 			ShipDeleteTrackingBranch: true,
 			SyncFeatureStrategy:      configdomain.SyncFeatureStrategyMerge,
 			SyncPerennialStrategy:    configdomain.SyncPerennialStrategyRebase,
+			SyncTags:                 true,
 			SyncUpstream:             true,
 		}
 		give.MainBranch = Some(gitdomain.NewLocalBranchName("main"))
@@ -103,6 +104,9 @@ create-prototype-branches = true
 # merging pull requests through its UI.
 ship-delete-tracking-branch = true
 
+# Should "git sync" sync tags with origin?
+sync-tags = true
+
 # Should "git sync" also fetch updates from the upstream remote?
 #
 # If an "upstream" remote exists, and this setting is enabled,
@@ -216,6 +220,9 @@ create-prototype-branches = false
 # merging pull requests through its UI.
 ship-delete-tracking-branch = true
 
+# Should "git sync" sync tags with origin?
+sync-tags = true
+
 # Should "git sync" also fetch updates from the upstream remote?
 #
 # If an "upstream" remote exists, and this setting is enabled,
