@@ -11,6 +11,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 type Runner interface {
@@ -33,14 +34,14 @@ func (self *Access) LoadLocal(updateOutdated bool) (configdomain.SingleSnapshot,
 	return self.load(configdomain.ConfigScopeLocal, updateOutdated)
 }
 
-func (self *Access) OriginRemote() string {
-	output, err := self.Query("git", "remote", "get-url", gitdomain.RemoteOrigin.String())
+func (self *Access) RemoteURL(remote gitdomain.Remote) Option[string] {
+	output, err := self.Query("git", "remote", "get-url", remote.String())
 	if err != nil {
 		// NOTE: it's okay to ignore the error here.
 		// If we get an error here, we simply don't use the origin remote.
-		return ""
+		return None[string]()
 	}
-	return strings.TrimSpace(output)
+	return NewOption(strings.TrimSpace(output))
 }
 
 func (self *Access) RemoveConfigValue(key configdomain.Key, scope configdomain.ConfigScope) error {
