@@ -9,10 +9,10 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/gitconfig"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/git/giturl"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/slice"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 type Runner interface {
@@ -70,21 +70,28 @@ func (self *UnvalidatedConfig) AddToPrototypeBranches(branches ...gitdomain.Loca
 // Tests can stub this through the GIT_TOWN_REMOTE environment variable.
 // Caches its result so can be called repeatedly.
 func (self *UnvalidatedConfig) OriginURL() Option[giturl.Parts] {
-	text := self.OriginURLString()
-	if text == "" {
-		return None[giturl.Parts]()
-	}
-	return confighelpers.DetermineOriginURL(text, self.Config.Value.HostingOriginHostname)
+	return self.RemoteURL(gitdomain.RemoteOrigin)
 }
 
-// OriginURLString provides the URL for the "origin" remote.
+// RemoteURL provides the URL for the given remote.
 // Tests can stub this through the GIT_TOWN_REMOTE environment variable.
-func (self *UnvalidatedConfig) OriginURLString() string {
-	remoteOverride := envconfig.OriginURLOverride()
-	if remoteOverride != "" {
+// Caches its result so can be called repeatedly.
+func (self *UnvalidatedConfig) RemoteURL(remote gitdomain.Remote) Option[giturl.Parts] {
+	text, hasText := self.RemoteURLString(remote).Get()
+	if !hasText {
+		return None[giturl.Parts]()
+	}
+	return confighelpers.DetermineRemoteURL(text, self.Config.Value.HostingOriginHostname)
+}
+
+// RemoteURLString provides the URL for the given remote.
+// Tests can stub this through the GIT_TOWN_REMOTE environment variable.
+func (self *UnvalidatedConfig) RemoteURLString(remote gitdomain.Remote) Option[string] {
+	remoteOverride := envconfig.RemoteURLOverride()
+	if remoteOverride.IsSome() {
 		return remoteOverride
 	}
-	return self.GitConfig.OriginRemote()
+	return self.GitConfig.RemoteURL(remote)
 }
 
 func (self *UnvalidatedConfig) RemoveCreatePrototypeBranches() {
@@ -165,6 +172,10 @@ func (self *UnvalidatedConfig) RemoveSyncPerennialStrategy() {
 	_ = self.GitConfig.RemoveLocalConfigValue(configdomain.KeySyncPerennialStrategy)
 }
 
+func (self *UnvalidatedConfig) RemoveSyncTags() {
+	_ = self.GitConfig.RemoveLocalConfigValue(configdomain.KeySyncTags)
+}
+
 func (self *UnvalidatedConfig) RemoveSyncUpstream() {
 	_ = self.GitConfig.RemoveLocalConfigValue(configdomain.KeySyncUpstream)
 }
@@ -259,9 +270,9 @@ func (self *UnvalidatedConfig) SetShipDeleteTrackingBranch(value configdomain.Sh
 	self.Config.Value.ShipDeleteTrackingBranch = value
 	switch scope {
 	case configdomain.ConfigScopeGlobal:
-		return self.GitConfig.SetGlobalConfigValue(configdomain.KeyShipDeleteTrackingBranch, strconv.FormatBool(value.Bool()))
+		return self.GitConfig.SetGlobalConfigValue(configdomain.KeyShipDeleteTrackingBranch, strconv.FormatBool(value.IsTrue()))
 	case configdomain.ConfigScopeLocal:
-		return self.GitConfig.SetLocalConfigValue(configdomain.KeyShipDeleteTrackingBranch, strconv.FormatBool(value.Bool()))
+		return self.GitConfig.SetLocalConfigValue(configdomain.KeyShipDeleteTrackingBranch, strconv.FormatBool(value.IsTrue()))
 	}
 	panic(messages.ConfigScopeUnhandled)
 }
@@ -277,14 +288,20 @@ func (self *UnvalidatedConfig) SetSyncPerennialStrategy(strategy configdomain.Sy
 	return self.GitConfig.SetLocalConfigValue(configdomain.KeySyncPerennialStrategy, strategy.String())
 }
 
+// SetSyncPerennialStrategy updates the configured sync-perennial strategy.
+func (self *UnvalidatedConfig) SetSyncTags(value configdomain.SyncTags) error {
+	self.Config.Value.SyncTags = value
+	return self.GitConfig.SetLocalConfigValue(configdomain.KeySyncTags, value.String())
+}
+
 // SetSyncUpstream updates the configured sync-upstream strategy.
 func (self *UnvalidatedConfig) SetSyncUpstream(value configdomain.SyncUpstream, scope configdomain.ConfigScope) error {
 	self.Config.Value.SyncUpstream = value
 	switch scope {
 	case configdomain.ConfigScopeGlobal:
-		return self.GitConfig.SetGlobalConfigValue(configdomain.KeySyncUpstream, strconv.FormatBool(value.Bool()))
+		return self.GitConfig.SetGlobalConfigValue(configdomain.KeySyncUpstream, strconv.FormatBool(value.IsTrue()))
 	case configdomain.ConfigScopeLocal:
-		return self.GitConfig.SetLocalConfigValue(configdomain.KeySyncUpstream, strconv.FormatBool(value.Bool()))
+		return self.GitConfig.SetLocalConfigValue(configdomain.KeySyncUpstream, strconv.FormatBool(value.IsTrue()))
 	}
 	panic(messages.ConfigScopeUnhandled)
 }
