@@ -29,6 +29,21 @@ func (self Connector) DefaultProposalMessage(proposal hostingdomain.Proposal) st
 }
 
 func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Option[hostingdomain.Proposal], error) {
+	self.log.Start(messages.APIProposalLookupStart)
+	proposalURLOverride := hostingdomain.ReadProposalOverride()
+	if len(proposalURLOverride) > 0 {
+		self.log.Success()
+		if proposalURLOverride == hostingdomain.OverrideNoProposal {
+			return None[hostingdomain.Proposal](), nil
+		}
+		return Some(hostingdomain.Proposal{
+			MergeWithAPI: true,
+			Number:       123,
+			Target:       target,
+			Title:        "title",
+			URL:          proposalURLOverride,
+		}), nil
+	}
 	openPullRequests, _, err := self.client.ListRepoPullRequests(self.Organization, self.Repository, gitea.ListPullRequestsOptions{
 		ListOptions: gitea.ListOptions{
 			PageSize: 50,
@@ -36,8 +51,10 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 		State: gitea.StateOpen,
 	})
 	if err != nil {
+		self.log.Failed(err)
 		return None[hostingdomain.Proposal](), err
 	}
+	self.log.Success()
 	pullRequests := FilterPullRequests(openPullRequests, self.Organization, branch, target)
 	switch len(pullRequests) {
 	case 0:
@@ -49,6 +66,7 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 			Number:       int(pullRequest.Index),
 			Target:       gitdomain.NewLocalBranchName(pullRequest.Base.Ref),
 			Title:        pullRequest.Title,
+			URL:          pullRequest.HTMLURL,
 		}), nil
 	default:
 		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFound, len(pullRequests), branch, target)
@@ -69,15 +87,20 @@ func (self Connector) SquashMergeProposal(number int, message gitdomain.CommitMe
 		return errors.New(messages.ProposalNoNumberGiven)
 	}
 	commitMessageParts := message.Parts()
+	self.log.Start(messages.HostingGithubMergingViaAPI, number)
 	_, _, err := self.client.MergePullRequest(self.Organization, self.Repository, int64(number), gitea.MergePullRequestOption{
 		Style:   gitea.MergeStyleSquash,
 		Title:   commitMessageParts.Subject,
 		Message: commitMessageParts.Text,
 	})
 	if err != nil {
+		self.log.Failed(err)
 		return err
 	}
+	self.log.Success()
+	self.log.Start(messages.APIProposalLookupStart)
 	_, _, err = self.client.GetPullRequest(self.Organization, self.Repository, int64(number))
+	self.log.Success()
 	return err
 }
 
