@@ -3,6 +3,6 @@ package gitea
 import "github.com/git-town/git-town/v15/internal/git/giturl"
 
 // Detect indicates whether the current repository is hosted on a GitHub server.
-func Detect(originURL giturl.Parts) bool {
-	return originURL.Host == "gitea.com"
+func Detect(remoteURL giturl.Parts) bool {
+	return remoteURL.Host == "gitea.com"
 }
