@@ -6,8 +6,8 @@ import (
 
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 type Data struct {
