@@ -4,6 +4,8 @@ const (
 	UndoContinueGuidance              = "\n\nTo continue after having resolved conflicts, run \"git town continue\".\nTo go back to where you started, run \"git town undo\".\n"
 	AliasedCommands                   = "Aliased commands: %s\n"
 	ArgumentUnknown                   = "unknown argument: %q"
+	APIProposalLookupStart            = "looking for proposal online ... "
+	APIProposalUpdateStart            = "updating proposal target online ..."
 	BranchAlreadyExistsLocally        = "there is already a branch %q"
 	BranchAlreadyExistsRemotely       = "there is already a branch %q at the \"origin\" remote"
 	BranchAuthorMultiple              = "\nMultiple people authored the %q branch.\n\n"
@@ -74,8 +76,8 @@ const (
 	FileReadProblem                   = "cannot read file %q: %w"
 	FileStatProblem                   = "cannot check file %q: %w"
 	FileWriteProblem                  = "cannot write file %q: %w"
-	FlagStringDoesntExist             = "command %q does not have a string %q flag"
 	GiteaToken                        = "Gitea token: %s\n"
+	GitAnotherProcessIsRunningRetry   = "another git process seems to be running in this repository, retrying in 1 sec ..."
 	GitHubEnterpriseInitializeError   = "cannot initialize GitHub Enterprise client: %s"
 	GitHubToken                       = "GitHub token: %s\n"
 	GitLabToken                       = "GitLab token: %s\n"
@@ -109,7 +111,6 @@ END OUTPUT FROM 'git branch -vva'
 	HostingGiteaNotImplemented            = "shipping pull requests via the Gitea API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
 	HostingGiteaUpdatePRViaAPI            = "Gitea API: Updating base branch for PR #%d to #%s"
 	HostingGithubMergingViaAPI            = "GitHub API: merging PR #%d ... "
-	HostingGithubUpdatePRViaAPI           = "GitHub API: updating base branch for PR #%d ... "
 	HostingPlatformUnknown                = "unknown hosting platform: %q"
 	InputAddOrRemove                      = `invalid argument %q. Please provide either "add" or "remove"`
 	InputYesOrNo                          = `invalid argument: %q. Please provide either "yes" or "no".\n`
