@@ -50,7 +50,7 @@ func syncFeatureBranchCompressProgram(args syncFeatureBranchProgramArgs) {
 	args.program.Value.Add(&opcodes.MergeParent{CurrentBranch: args.localName, ParentActiveInOtherWorktree: args.parentOtherWorktree})
 	if firstCommitMessage, branchHasCommits := args.firstCommitMessage.Get(); branchHasCommits {
 		args.program.Value.Add(&opcodes.ResetCurrentBranchToParent{CurrentBranch: args.localName})
-		args.program.Value.Add(&opcodes.CommitOpenChanges{AddAll: false, Message: firstCommitMessage})
+		args.program.Value.Add(&opcodes.CommitOpenChanges{Message: firstCommitMessage})
 	}
 	if hasTrackingBranch && args.offline.IsFalse() {
 		args.program.Value.Add(&opcodes.ForcePushCurrentBranch{ForceIfIncludes: false})
