@@ -8,11 +8,11 @@ import (
 	"github.com/git-town/git-town/v15/internal/config"
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/vm/program"
 	"github.com/git-town/git-town/v15/internal/vm/shared"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 func Execute(args ExecuteArgs) {
