@@ -19,6 +19,7 @@ type ConnectorMergeProposal struct {
 	ProposalNumber            int
 	enteredEmptyCommitMessage bool
 	mergeError                error
+	undeclaredOpcodeMethods   `exhaustruct:"optional"`
 }
 
 func (self *ConnectorMergeProposal) CreateAbortProgram() []shared.Opcode {
@@ -35,10 +36,6 @@ func (self *ConnectorMergeProposal) CreateAutomaticUndoError() error {
 	return self.mergeError
 }
 
-func (self *ConnectorMergeProposal) CreateContinueProgram() []shared.Opcode {
-	return []shared.Opcode{self}
-}
-
 func (self *ConnectorMergeProposal) Run(args shared.RunArgs) error {
 	commitMessage, hasCommitMessage := self.CommitMessage.Get()
 	//nolint:nestif
