@@ -71,6 +71,7 @@ func Types() []shared.Opcode {
 		&DeleteParentBranch{},
 		&DeleteTrackingBranch{},
 		&DiscardOpenChanges{},
+		&DropStash{},
 		&EndOfBranchProgram{},
 		&EnsureHasShippableChanges{},
 		&FetchUpstream{},
@@ -105,6 +106,7 @@ func Types() []shared.Opcode {
 		&SetParent{},
 		&SetParentIfBranchExists{},
 		&SkipCurrentBranch{},
+		&StageOpenChanges{},
 		&StashOpenChanges{},
 		&SquashMerge{},
 		&UndoLastCommit{},
