@@ -12,10 +12,6 @@ type CreateTrackingBranch struct {
 	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
-func (self *CreateTrackingBranch) CreateContinueProgram() []shared.Opcode {
-	return []shared.Opcode{self}
-}
-
 func (self *CreateTrackingBranch) Run(args shared.RunArgs) error {
 	return args.Git.CreateTrackingBranch(args.Frontend, self.Branch, gitdomain.RemoteOrigin, args.Config.Config.NoPushHook())
 }
