@@ -6,6 +6,7 @@ import (
 
 // ForcePushCurrentBranch force-pushes the branch with the given name to the origin remote.
 type ForcePushCurrentBranch struct {
+	ForceIfIncludes         bool
 	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
@@ -14,12 +15,12 @@ func (self *ForcePushCurrentBranch) Run(args shared.RunArgs) error {
 	if err != nil {
 		return err
 	}
-	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, currentBranch, currentBranch.TrackingBranch())
+	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, currentBranch)
 	if err != nil {
 		return err
 	}
 	if !shouldPush {
 		return nil
 	}
-	return args.Git.ForcePushBranchSafely(args.Frontend, args.Config.Config.NoPushHook())
+	return args.Git.ForcePushBranchSafely(args.Frontend, args.Config.Config.NoPushHook(), self.ForceIfIncludes)
 }
