@@ -7,11 +7,11 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v15/internal/vm/opcodes"
 	"github.com/git-town/git-town/v15/internal/vm/program"
 	"github.com/git-town/git-town/v15/internal/vm/shared"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // RunState represents the current state of a Git Town command,
@@ -38,8 +38,7 @@ func EmptyRunState() RunState {
 	return RunState{} //exhaustruct:ignore
 }
 
-// AddPushBranchAfterCurrentBranchProgram inserts a PushBranch opcode
-// after all the opcodes for the current branch.
+// inserts a PushBranch opcode after all the opcodes for the current branch
 func (self *RunState) AddPushBranchAfterCurrentBranchProgram(gitCommands git.Commands, backend gitdomain.Querier) error {
 	popped := program.Program{}
 	for {
