@@ -58,7 +58,7 @@ func TestLoadSave(t *testing.T) {
 					Parent: gitdomain.NewLocalBranchName("parent"),
 				},
 				&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.CommitOpenChanges{AddAll: true, Message: "my message"},
+				&opcodes.CommitOpenChanges{Message: "my message"},
 				&opcodes.ConnectorMergeProposal{
 					Branch:          gitdomain.NewLocalBranchName("branch"),
 					CommitMessage:   Some(gitdomain.CommitMessage("commit message")),
@@ -90,6 +90,7 @@ func TestLoadSave(t *testing.T) {
 					Branch: gitdomain.NewRemoteBranchName("origin/branch"),
 				},
 				&opcodes.DiscardOpenChanges{},
+				&opcodes.DropStash{},
 				&opcodes.EndOfBranchProgram{},
 				&opcodes.EnsureHasShippableChanges{
 					Branch: gitdomain.NewLocalBranchName("branch"),
@@ -172,6 +173,7 @@ func TestLoadSave(t *testing.T) {
 					CommitMessage: Some(gitdomain.CommitMessage("commit message")),
 					Parent:        gitdomain.NewLocalBranchName("parent"),
 				},
+				&opcodes.StageOpenChanges{},
 				&opcodes.StashOpenChanges{},
 				&opcodes.UpdateProposalTarget{
 					ProposalNumber: 123,
@@ -259,7 +261,6 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "AddAll": true,
         "Message": "my message"
       },
       "type": "CommitOpenChanges"
@@ -332,6 +333,10 @@ func TestLoadSave(t *testing.T) {
       "data": {},
       "type": "DiscardOpenChanges"
     },
+    {
+      "data": {},
+      "type": "DropStash"
+    },
     {
       "data": {},
       "type": "EndOfBranchProgram"
@@ -510,6 +515,10 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "SquashMerge"
     },
+    {
+      "data": {},
+      "type": "StageOpenChanges"
+    },
     {
       "data": {},
       "type": "StashOpenChanges"
