@@ -11,9 +11,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	prodgit "github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/slice"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/git-town/git-town/v15/test/asserts"
 	"github.com/git-town/git-town/v15/test/datatable"
 	"github.com/git-town/git-town/v15/test/git"
@@ -63,8 +63,8 @@ func (self *TestCommands) CommitSHAs() map[string]gitdomain.SHA {
 }
 
 // CommitStagedChanges commits the currently staged changes.
-func (self *TestCommands) CommitStagedChanges(message string) {
-	self.MustRun("git", "commit", "-m", message)
+func (self *TestCommands) CommitStagedChanges(message gitdomain.CommitMessage) {
+	self.MustRun("git", "commit", "-m", message.String())
 }
 
 // Commits provides a list of the commits in this Git repository with the given fields.
@@ -88,8 +88,8 @@ func (self *TestCommands) CommitsInBranch(branch gitdomain.LocalBranchName, fiel
 	result := []git.Commit{}
 	for _, line := range strings.Split(output, "\n") {
 		parts := strings.Split(line, "|")
-		commit := git.Commit{Branch: branch, SHA: gitdomain.NewSHA(parts[0]), Message: parts[1], Author: parts[2]}
-		if strings.EqualFold(commit.Message, "initial commit") || strings.EqualFold(commit.Message, ConfigFileCommitMessage) {
+		commit := git.Commit{Branch: branch, SHA: gitdomain.NewSHA(parts[0]), Message: gitdomain.CommitMessage(parts[1]), Author: gitdomain.Author(parts[2])}
+		if strings.EqualFold(commit.Message.String(), "initial commit") || strings.EqualFold(commit.Message.String(), ConfigFileCommitMessage) {
 			continue
 		}
 		if slices.Contains(fields, "FILE NAME") {
@@ -114,14 +114,14 @@ func (self *TestCommands) ConnectTrackingBranch(name gitdomain.LocalBranchName)
 // CreateBranch creates a new branch with the given name.
 // The created branch is a normal branch.
 // To create feature branches, use CreateFeatureBranch.
-func (self *TestCommands) CreateBranch(name, parent gitdomain.LocalBranchName) {
+func (self *TestCommands) CreateBranch(name gitdomain.LocalBranchName, parent gitdomain.BranchName) {
 	self.MustRun("git", "branch", name.String(), parent.String())
 }
 
 // CreateChildFeatureBranch creates a branch with the given name and parent in this repository.
 // The parent branch must already exist.
 func (self *TestCommands) CreateChildFeatureBranch(branch gitdomain.LocalBranchName, parent gitdomain.LocalBranchName) {
-	self.CreateBranch(branch, parent)
+	self.CreateBranch(branch, parent.BranchName())
 	asserts.NoError(self.Config.SetParent(branch, parent))
 }
 
@@ -130,9 +130,9 @@ func (self *TestCommands) CreateCommit(commit git.Commit) {
 	self.CheckoutBranch(commit.Branch)
 	self.CreateFile(commit.FileName, commit.FileContent)
 	self.MustRun("git", "add", commit.FileName)
-	commands := []string{"commit", "-m", commit.Message}
+	commands := []string{"commit", "-m", commit.Message.String()}
 	if commit.Author != "" {
-		commands = append(commands, "--author="+commit.Author)
+		commands = append(commands, "--author="+commit.Author.String())
 	}
 	self.MustRun("git", commands...)
 }
@@ -144,7 +144,7 @@ func (self *TestCommands) CreateContributionBranch(name gitdomain.LocalBranchNam
 }
 
 // creates a feature branch with the given name in this repository
-func (self *TestCommands) CreateFeatureBranch(name, parent gitdomain.LocalBranchName) {
+func (self *TestCommands) CreateFeatureBranch(name gitdomain.LocalBranchName, parent gitdomain.BranchName) {
 	self.CreateBranch(name, parent)
 	self.MustRun("git", "config", "git-town-branch."+name.String()+".parent", parent.String())
 }
@@ -172,7 +172,7 @@ func (self *TestCommands) CreateObservedBranch(name gitdomain.LocalBranchName) {
 
 // creates a parked branch with the given name and parent in this repository
 func (self *TestCommands) CreateParkedBranch(name, parent gitdomain.LocalBranchName) {
-	self.CreateFeatureBranch(name, parent)
+	self.CreateFeatureBranch(name, parent.BranchName())
 	asserts.NoError(self.Config.AddToParkedBranches(name))
 }
 
@@ -184,7 +184,7 @@ func (self *TestCommands) CreatePerennialBranch(name gitdomain.LocalBranchName)
 
 // creates a prototype branch with the given name and parent in this repository
 func (self *TestCommands) CreatePrototypeBranch(name, parent gitdomain.LocalBranchName) {
-	self.CreateFeatureBranch(name, parent)
+	self.CreateFeatureBranch(name, parent.BranchName())
 	asserts.NoError(self.Config.AddToPrototypeBranches(name))
 }
 
