@@ -1,6 +1,6 @@
 package datatable
 
-import "github.com/git-town/git-town/v14/src/git/gitdomain"
+import "github.com/git-town/git-town/v15/internal/git/gitdomain"
 
 type runner interface {
 	SHAsForCommit(name string) gitdomain.SHAs
