@@ -14,6 +14,7 @@ import (
 
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/subshell"
 	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/git-town/git-town/v15/test/asserts"
@@ -33,6 +34,9 @@ type TestRunner struct {
 	// the directory that contains the global Git configuration
 	HomeDir string
 
+	// content of the GIT_TOWN_TEST_PROPOSAL environment variable
+	ProposalOverride Option[string]
+
 	// whether to log the output of subshell commands
 	Verbose configdomain.Verbose
 
@@ -198,6 +202,9 @@ func (self *TestRunner) QueryWithCode(opts *Options, cmd string, args ...string)
 	if testOrigin, hasTestOrigin := self.testOrigin.Get(); hasTestOrigin {
 		opts.Env = envvars.Replace(opts.Env, "GIT_TOWN_REMOTE", testOrigin)
 	}
+	if proposalOverride, hasProposalOverride := self.ProposalOverride.Get(); hasProposalOverride {
+		opts.Env = envvars.Replace(opts.Env, hostingdomain.OverrideKey, proposalOverride)
+	}
 	// add the custom bin dir to the PATH
 	if self.usesBinDir {
 		opts.Env = envvars.PrependPath(opts.Env, self.BinDir)
@@ -271,6 +278,11 @@ func (self *TestRunner) Run(name string, arguments ...string) error {
 	return err
 }
 
+// SetTestOrigin adds the given environment variable to subsequent runs of commands.
+func (self *TestRunner) SetProposalOverride(content string) {
+	self.ProposalOverride = Some(content)
+}
+
 // SetTestOrigin adds the given environment variable to subsequent runs of commands.
 func (self *TestRunner) SetTestOrigin(content string) {
 	self.testOrigin = Some(content)
